@@ -1,12 +1,13 @@
 ##----------------------------------------------------------------------------
 ## DateTime Format Relative Time - ~/lib/DateTime/Format/RelativeTime.pm
-## Version v0.1.0
-## Copyright(c) 2024-2025 DEGUEST Pte. Ltd.
+## Version v0.1.1
+## Copyright(c) 2025 DEGUEST Pte. Ltd.
 ## Author: Jacques Deguest <jack@deguest.jp>
 ## Created 2024/12/30
-## Modified 2025/01/03
+## Modified 2025/01/04
 ## All rights reserved
 ## 
+## 
 ## This program is free software; you can redistribute  it  and/or  modify  it
 ## under the same terms as Perl itself.
 ##----------------------------------------------------------------------------
@@ -26,7 +27,7 @@ BEGIN
     use Locale::Unicode::Data v1.3.0;
     use Scalar::Util ();
     use Want;
-    our $VERSION = 'v0.1.0';
+    our $VERSION = 'v0.1.1';
 };
 
 use strict;
@@ -432,10 +433,10 @@ sub format_to_parts
                 type => 'RangeError',
                 message => "Supported unit value must be one of: 'year', 'quarter', 'month', 'week', 'day', 'hour', 'minute', 'second'"
             }) );
-            $unit = lc( $unit );
-            # Remove the 's' at the end if there is one
-            $unit = substr( $unit, 0, -1 ) if( substr( $unit, -1, 1 ) eq 's' );
         }
+        $unit = lc( $unit );
+        # Remove the 's' at the end if there is one
+        $unit = substr( $unit, 0, -1 ) if( substr( $unit, -1, 1 ) eq 's' );
         # $num could be 0.0, and this edge case would disrupt formatting, so we need to transform it to a simple 0
         # Using sprintf also ensures .5 becomes 0.5, or -.5 becomes -0.5
         $num = sprintf( '%.15g', $num );
@@ -495,14 +496,18 @@ sub format_to_parts
     if( !defined( $pattern ) )
     {
         my $count = $cldr->plural_count( abs( $num ), $locale );
+        $self->_message( 4, "Count for number '${num}' and locale '${locale}' is '${count}'" );
         my $cldr_num = ( $num < 0 ? -1 : 1 );
         LOCALE: foreach my $loc ( @$tree )
         {
+            $self->_message( 4, "Checking locale '${locale}' -> '${loc}'" );
             foreach my $this_style ( @styles )
             {
+                $self->_message( 4, "\tChecking for style '${this_style}'" );
                 # As a safe fallback, we add 'other'
-                foreach my $cnt ( $count, 'other' )
+                foreach my $cnt ( $count, ( $count ne 'other' ? ( 'other' ) : () ) )
                 {
+                    $self->_message( 4, "Trying to get the time relative pattern for count '${cnt}', field_type '${unit}', field_length '${this_style}', relative '${cldr_num}'" );
                     my $ref = $cldr->time_relative_l10n(
                         locale => $loc,
                         field_type => $unit,
@@ -511,7 +516,8 @@ sub format_to_parts
                         count => $cnt,
                     );
                     return( $self->pass_error( $cldr->error ) ) if( !defined( $ref ) && $cldr->error );
-                    if( $ref )
+                    $self->_message( 4, "\$cldr->time_relative_l10n() returned: ", sub{ dump( $ref ) } );
+                    if( $ref && scalar( keys( %$ref ) ) )
                     {
                         $pattern = $ref->{format_pattern};
                         last LOCALE;
@@ -1120,7 +1126,7 @@ For users requiring exact decimal representation beyond this precision, consider
 
 =head1 VERSION
 
-    v0.1.0
+    v0.1.1
 
 =head1 DESCRIPTION
 
